<?php

namespace App\Command\Migration;

use App\Entity\OrganizationalUnit;
use App\Entity\Software;
use App\Entity\SoftwareProfile;
use Doctrine\ORM\EntityManagerInterface;
use Doctrine\ORM\Query\ResultSetMapping;
use Doctrine\Persistence\ManagerRegistry;
use Symfony\Component\Console\Attribute\AsCommand;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

#[AsCommand(name: 'opengnsys:migration:software-profile', description: 'Migrate software and software profile data')]
class MigrateSoftwareAndSoftwareProfileCommand extends Command
{
    public function __construct(
        private readonly EntityManagerInterface $entityManager,
        private readonly ManagerRegistry $doctrine
    )
    {
        parent::__construct();
    }

    protected function execute(InputInterface $input, OutputInterface $output): void
    {
        /** @var EntityManagerInterface $oldDatabaseEntityManager */
        $oldDatabaseEntityManager = $this->doctrine->getManager('og_1');

        $organizationalUnitRepository = $this->entityManager->getRepository(OrganizationalUnit::class);
        $softwareProfileRepository = $this->entityManager->getRepository(SoftwareProfile::class);
        $softwareRepository = $this->entityManager->getRepository(Software::class);

        /** Obtener los perfiles software de la base de datos antigua **/
        $rsmSoftware = new ResultSetMapping();
        $rsmSoftware->addScalarResult('idtiposoftware', 'idtiposoftware');
        $rsmSoftware->addScalarResult('descripcion', 'descripcion');

        $softwareQuery = $oldDatabaseEntityManager->createNativeQuery('SELECT idtiposoftware, descripcion FROM softwares', $rsmSoftware);
        $softwareCollection = $softwareQuery->getResult();

        foreach ($softwareCollection as $software) {
            $softwareEntity = null;
            $softwareEntity = $softwareRepository->findOneBy(['migrationId' => $software['idtiposoftware']]);
            if (!$softwareEntity) {
                $softwareEntity = new Software();
                $softwareEntity->setMigrationId($software['idtiposoftware']);
                $softwareEntity->setName($software['descripcion']);
                $softwareEntity->setDescription($software['descripcion']);
            }

            $this->entityManager->persist($softwareEntity);
        }
    }
}