<?php

namespace App\Entity;

use App\Repository\CommandRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity(repositoryClass: CommandRepository::class)]
class Command extends AbstractEntity
{
    use NameableTrait;
    use ToggleableTrait;

    #[ORM\Column(length: 255)]
    private ?string $script = null;

    #[ORM\Column(length: 255, nullable: true)]
    private ?string $comments = null;

    #[ORM\Column]
    private ?bool $readOnly = null;

    /**
     * @var Collection<int, CommandGroup>
     */
    #[ORM\ManyToMany(targetEntity: CommandGroup::class, mappedBy: 'commands')]
    private Collection $commandGroups;

    public function __construct()
    {
        parent::__construct();
        $this->commandGroups = new ArrayCollection();
    }

    public function getScript(): ?string
    {
        return $this->script;
    }

    public function setScript(string $script): static
    {
        $this->script = $script;

        return $this;
    }

    public function getComments(): ?string
    {
        return $this->comments;
    }

    public function setComments(?string $comments): static
    {
        $this->comments = $comments;

        return $this;
    }

    public function isReadOnly(): ?bool
    {
        return $this->readOnly;
    }

    public function setReadOnly(bool $readOnly): static
    {
        $this->readOnly = $readOnly;

        return $this;
    }

    /**
     * @return Collection<int, CommandGroup>
     */
    public function getCommandGroups(): Collection
    {
        return $this->commandGroups;
    }

    public function addCommandGroup(CommandGroup $commandGroup): static
    {
        if (!$this->commandGroups->contains($commandGroup)) {
            $this->commandGroups->add($commandGroup);
            $commandGroup->addCommand($this);
        }

        return $this;
    }

    public function removeCommandGroup(CommandGroup $commandGroup): static
    {
        if ($this->commandGroups->removeElement($commandGroup)) {
            $commandGroup->removeCommand($this);
        }

        return $this;
    }
}
