<?php

namespace App\State\Processor;

use ApiPlatform\Metadata\Delete;
use ApiPlatform\Metadata\Operation;
use ApiPlatform\Metadata\Patch;
use ApiPlatform\Metadata\Post;
use ApiPlatform\Metadata\Put;
use ApiPlatform\State\ProcessorInterface;
use ApiPlatform\Validator\ValidatorInterface;
use App\Dto\Input\MenuInput;
use App\Dto\Input\PartitionInput;
use App\Dto\Input\UserGroupInput;
use App\Dto\Output\MenuOutput;
use App\Dto\Output\PartitionOutput;
use App\Dto\Output\UserGroupOutput;
use App\Repository\MenuRepository;
use App\Repository\PartitionRepository;
use App\Repository\UserGroupRepository;

readonly class PartitionProcessor implements ProcessorInterface
{
    public function __construct(
        private PartitionRepository $partitionRepository,
        private ValidatorInterface  $validator
    )
    {
    }

    /**
     * @throws \Exception
     */
    public function process(mixed $data, Operation $operation, array $uriVariables = [], array $context = []): PartitionOutput|null
    {
        switch ($operation){
            case $operation instanceof Post:
            case $operation instanceof Put:
            case $operation instanceof Patch:
                return $this->processCreateOrUpdate($data, $operation, $uriVariables, $context);
            case $operation instanceof Delete:
                return $this->processDelete($data, $operation, $uriVariables, $context);
        }
    }

    /**
     * @throws \Exception
     */
    private function processCreateOrUpdate($data, Operation $operation, array $uriVariables = [], array $context = []): PartitionOutput
    {
        if (!($data instanceof PartitionInput)) {
            throw new \Exception(sprintf('data is not instance of %s', PartitionInput::class));
        }

        $entity = null;
        if (isset($uriVariables['uuid'])) {
            $entity = $this->partitionRepository->findOneByUuid($uriVariables['uuid']);
        }

        $partition = $data->createOrUpdateEntity($entity);
        $this->validator->validate($partition);
        $this->partitionRepository->save($partition);

        return new PartitionOutput($partition);
    }

    private function processDelete($data, Operation $operation, array $uriVariables = [], array $context = []): null
    {
        $user = $this->partitionRepository->findOneByUuid($uriVariables['uuid']);
        $this->partitionRepository->delete($user);

        return null;
    }
}
